@@ -6,4 +6,4 @@
 # All rights reserved.
 # -------------------------------
 
-from .juniper_source import exec
\ No newline at end of file
+# Juniper CS is a Package intended to be executed from its inner Main Script
\ No newline at end of file
