@@ -6,7 +6,7 @@
 # All rights reserved.
 # -------------------------------
 
-import juniper_source as jp
+from juniper_source import exec
 import os
 
 def main(): 
@@ -27,7 +27,7 @@ def main():
     while(True):
         print("\n <{0}> Juniper CS - Session: {1} [ {2} ]".format(str(commandCounter),sessionName,str(os.getcwd())))
         command = input(" - ")
-        jp.exec(command)
+        exec(command)
         commandCounter += 1
 
     return # Unreachable
